pub struct Location {
pub line: usize,
pub column: Option<usize>,
}Expand description
A source location with line and column.
Both line and column are 1-indexed. A value of 0 for either is
considered a caller bug and will produce an error.
Fields
line: usize1-indexed line number.
column: Option<usize>1-indexed column as a byte offset into the line. None means no
column highlighting — only the line itself is highlighted.